#!/usr/bin/env python

from setuptools import find_packages, setup

from {{ module_name }} import __version__

with open('README.md', 'r') as f:
    long_description = f.read()

setup(
    name='{{ package_name }}',
    version=__version__,
    author='{{ author }}',
    author_email='{{ author_email }}',
    description='{{ description }}',
    long_description=long_description,
    long_description_content_type='text/markdown',
    url='{{ url }}',
    packages=find_packages(),
    include_package_data={{ include_package_data }},
    install_requires=['docopt'],
    entry_points={
        'console_scripts': ['{{ package_name }}={{ module_name }}.cli:main']
    },
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Topic :: Software Development'
    ],
    python_requires='>=3.6',
)
